This is a simple library that performs
basic django and bootstrap component.

## Installation
```
pip install djbs

```

## Usage:
A guide to using the djbs cli is as follows

```
python -m djbs startapp <app-name>

```
The functions in this library are:
1. new app django
2. new component bootstrap

## License
Copyright 2022 jamalelkhdadi

This repository is licensed under MIT license.
See LICENSE for details.
